@@ -16,9 +16,7 @@ def confirm_destructive_query(queries):
     * False if the query is destructive and the user doesn't want to proceed.
 
     """
-    prompt_text = (
-        "You're about to run a destructive command.\n" "Do you want to proceed? (y/n)"
-    )
+    prompt_text = "You're about to run a destructive command.\n" "Do you want to proceed? (y/n)"
     if is_destructive(queries) and sys.stdin.isatty():
         return prompt(prompt_text, type=bool)
 
