@@ -138,14 +138,14 @@ qwq
 > \\llm models default llama3
 
 # Set api key (not required for local models)
-> \\llm keys set openai sg-1234
-API key set for openai.
+> \\llm keys set openai
+
 
 # Install a model plugin
 > \\llm install llm-ollama
 llm-ollama installed.
 
-# Models directory
+# Plugins directory
 # https://llm.datasette.io/en/stable/plugins/directory.html
 """
 
@@ -285,6 +285,8 @@ def is_llm_command(command) -> bool:
 
 @export
 def sql_using_llm(cur, question=None, verbose=False) -> Tuple[str, Optional[str]]:
+    if cur is None:
+        raise RuntimeError("Connect to a datbase and try again.")
     schema_query = """
         SELECT sql FROM sqlite_master
         WHERE sql IS NOT NULL
