@@ -9,6 +9,7 @@ from prompt_toolkit.completion import Completer, Completion
 from .packages.completion_engine import suggest_type
 from .packages.parseutils import last_word
 from .packages.special.iocommands import favoritequeries
+from .packages.special import llm
 from .packages.filepaths import parse_path, complete_path, suggest_path
 
 _logger = logging.getLogger(__name__)
@@ -267,11 +268,7 @@ class SQLCompleter(Completer):
         self.reset_completions()
 
     def escape_name(self, name):
-        if name and (
-            (not self.name_pattern.match(name))
-            or (name.upper() in self.reserved_words)
-            or (name.upper() in self.functions)
-        ):
+        if name and ((not self.name_pattern.match(name)) or (name.upper() in self.reserved_words) or (name.upper() in self.functions)):
             name = "`%s`" % name
 
         return name
@@ -437,10 +434,7 @@ class SQLCompleter(Completer):
                 return kw.upper()
             return kw.lower()
 
-        return (
-            Completion(z if casing is None else apply_case(z), -len(text))
-            for x, y, z in sorted(completions)
-        )
+        return (Completion(z if casing is None else apply_case(z), -len(text)) for x, y, z in sorted(completions))
 
     def get_completions(self, document, complete_event):
         word_before_cursor = document.get_word_before_cursor(WORD=True)
@@ -458,11 +452,7 @@ class SQLCompleter(Completer):
                     # drop_unique is used for 'tb11 JOIN tbl2 USING (...'
                     # which should suggest only columns that appear in more than
                     # one table
-                    scoped_cols = [
-                        col
-                        for (col, count) in Counter(scoped_cols).items()
-                        if count > 1 and col != "*"
-                    ]
+                    scoped_cols = [col for (col, count) in Counter(scoped_cols).items() if count > 1 and col != "*"]
 
                 cols = self.find_matches(word_before_cursor, scoped_cols)
                 completions.extend(cols)
@@ -535,13 +525,24 @@ class SQLCompleter(Completer):
                 )
                 completions.extend(queries)
             elif suggestion["type"] == "table_format":
-                formats = self.find_matches(
-                    word_before_cursor, self.table_formats, start_only=True, fuzzy=False
-                )
+                formats = self.find_matches(word_before_cursor, self.table_formats, start_only=True, fuzzy=False)
                 completions.extend(formats)
             elif suggestion["type"] == "file_name":
                 file_names = self.find_files(word_before_cursor)
                 completions.extend(file_names)
+            elif suggestion["type"] == "llm":
+                if not word_before_cursor:
+                    tokens = document.text.split()[1:]
+                else:
+                    tokens = document.text.split()[1:-1]
+                possible_entries = llm.get_completions(tokens)
+                subcommands = self.find_matches(
+                    word_before_cursor,
+                    possible_entries,
+                    start_only=False,
+                    fuzzy=True,
+                )
+                completions.extend(subcommands)
 
         return completions
 
